@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 def format_code(source):
@@ -49,16 +49,13 @@ def format_code(source):
 def starts_with_triple(string):
     """Return True if the string starts with triple single/double quotes."""
     return (string.strip().startswith('"""') or
-            string.strip().startswith("''''"))
+            string.strip().startswith("'''"))
 
 
 def format_docstring(indentation, docstring):
     """Return formatted version of docstring."""
     contents = strip_docstring(docstring)
 
-    if not contents:
-        return ''
-
     summary, description = split_summary_and_description(contents)
 
     if description:
@@ -73,7 +70,7 @@ def format_docstring(indentation, docstring):
                                   for l in description.split('\n')]),
            indentation=indentation)
     else:
-        return '"""' + contents + '"""'
+        return '"""' + normalize_summary(contents) + '"""'
 
 
 def indent_non_indented(line, indentation):
@@ -117,6 +114,43 @@ def normalize_summary(summary):
     summary = re.sub('\s*\n\s*', ' ', summary.strip())
 
     # Add period at end of sentence
-    if not summary.endswith('.'):
+    if summary and not summary.endswith('.'):
         summary += '.'
+
     return summary
+
+
+def main(argv, output_file):
+    """Main entry point."""
+    import argparse
+    parser = argparse.ArgumentParser(description=__doc__)
+    parser.add_argument('--in-place', action='store_true',
+                        help='make changes to file instead of printing diff')
+    parser.add_argument('--no-backup', dest='backup', action='store_false',
+                        help='do not write backup files')
+    parser.add_argument('--version', action='version', version=__version__)
+    parser.add_argument('files', nargs='+',
+                        help='files to format')
+
+    args = parser.parse_args(argv)
+
+    for filename in args.files:
+        with open(filename) as input_file:
+            source = input_file.read()
+            formatted_source = format_code(source)
+
+        if args.in_place:
+            if args.backup:
+                with open(filename + '.backup', 'w') as backup_file:
+                    backup_file.write(source)
+
+            with open(filename, 'w') as output_file:
+                output_file.write(formatted_source)
+        else:
+            import difflib
+            diff = difflib.unified_diff(
+                    [l + '\n' for l in source.split('\n')],
+                    [l + '\n' for l in formatted_source.split('\n')],
+                    'before/' + filename,
+                    'after/' + filename)
+            output_file.write(''.join(diff))
